import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:flutter/material.dart';
import 'package:urbetrack_fcm_configuration/urbetrack_fcm_configuration.dart';

String _token;
void main() {
  WidgetsFlutterBinding.ensureInitialized();

  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'FCM Configuration Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'FCM Configuration Demo'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key key, this.title}) : super(key: key);
  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  Widget build(BuildContext context) {
    FCMConfiguration.initialize(
      onNotificationPressed: (data) {
        ScaffoldMessenger.of(context).showSnackBar(SnackBar(content: Text(data.toString())));
      },
      onTokenChanged: (token) {
        _token = token;
      },
    );
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Text(
              'FCM Configuration',
            ),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: () => sendPushMessage(_token),
        tooltip: 'Send Notification',
        child: Icon(Icons.notifications_active),
      ),
    );
  }

  int _messageCount = 0;

  /// The API endpoint here accepts a raw FCM payload for demonstration purposes.
  String constructFCMPayload(String token) {
    _messageCount++;
    return jsonEncode({
      "to": token,
      "notification": {
        "body": "body",
        "title": "title",
        "content_available": true,
        "priority": "high",
      },
      "data": {
        "token-in-data": token,
      }
    });
  }

  Future<void> sendPushMessage(String token) async {
    if (token == null) {
      print('Unable to send FCM message, no token exists.');
      return;
    }

    try {
      await http.post(
        Uri.parse('https://fcm.googleapis.com/fcm/send'),
        headers: <String, String>{
          'Content-Type': 'application/json',
          'Authorization':
              'key=AAAAGbqMiaE:APA91bE7fV0dicFQugCyBcIItvolvHy37qa8SIlZH8MMbXEk-jrNqLfevPmiIYzB5oGJE4NLbr0-y3jmEBq_xAwwzi5BFzhLrHbhlv0JDzsXEkKsHP8nNYsM7VOiNlh3jpYqYargIBnO',
        },
        body: constructFCMPayload(token),
      );
      print('FCM request for device sent!');
    } catch (e) {
      print(e);
    }
  }
}
