import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:urbetrack_fcm_configuration/src/local_notification.dart';

class FCMConfiguration {
  static initialize({
    void onNotificationPressed(Map<String, dynamic> data),
    void onTokenChanged(String token),
  }) async {
    await LocalNotification.initializeLocalNotification(
        onNotificationPressed: onNotificationPressed, icon: 'ic_launcher');

    // Initialize firebaseApp instance
    await Firebase.initializeApp();

    // Execute function when token is created or else refreshed
    FirebaseMessaging.instance.getToken().then(onTokenChanged);
    FirebaseMessaging.instance.onTokenRefresh.listen(onTokenChanged);

    // Set the background messaging handler

    FirebaseMessaging.onBackgroundMessage(_firebaseMessagingBackgroundHandler);

    /// Update the iOS foreground notification presentation options to allow
    /// heads up notifications.
    await FirebaseMessaging.instance.setForegroundNotificationPresentationOptions(
      alert: true,
      badge: true,
      sound: true,
    );

    // If the application is opened terminated from a notification
    FirebaseMessaging.instance.getInitialMessage().then((RemoteMessage message) {
      if (message != null) {
        print(message);
      }
    });

    // Foreground message listener
    FirebaseMessaging.onMessage.listen((RemoteMessage message) {
      RemoteNotification notification = message.notification;
      AndroidNotification android = message.notification?.android;

      if (notification != null && android != null) {
        LocalNotification.showNotification(
          notification: notification,
          payload: message.data,
        );
      }
    });

    FirebaseMessaging.onMessageOpenedApp.listen((RemoteMessage message) {
      onNotificationPressed(message.data);
    });

    FirebaseMessaging.onBackgroundMessage((RemoteMessage message) async {
      onNotificationPressed(message.data);
    });
  }

  static Future<void> _firebaseMessagingBackgroundHandler(RemoteMessage message) async {
    await Firebase.initializeApp();
    print('Handling a background message ${message.messageId}');
  }
}
